=======
Credits
=======

Very loosely based on https://github.com/OVChip/ovchipapi-python for the
authentication part.


Development Lead
----------------

* Costas Tyfoxylos <costas.tyf@gmail.com>

Contributors
------------

None yet. Why not be the first?
